---
name: Feature request
about: Suggest an idea for this project
title: 'feat(ISSUE-*): '
labels: enhancement
assignees: ''

---

### Feature Request

**Problem**  
Why is this needed? Describe the issue or challenge this feature addresses.

**Outcome**
What will success look like? Describe the positive impact of solving this problem.

**Tests**  
Does this PR has unit tests ?

**Additional Context** (optional)
Any extra details or references for background.
